==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/FinancialSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsDescriptionMetadata } from "./AssigningCategoryStyleEventArgsDescriptionMetadata";
import { FinancialEventArgsDescriptionMetadata } from "./FinancialEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
export let FinancialSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialSeriesDescriptionMetadata.a == null) {
                FinancialSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialSeriesDescriptionMetadata.c(FinancialSeriesDescriptionMetadata.a);
            }
            if (a.k(FinancialSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(FinancialSeriesDescriptionMetadata.a);
            AssigningCategoryStyleEventArgsDescriptionMetadata.d(a);
            FinancialEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            SeriesDescriptionMetadata.c(a);
            a.item("NegativeBrush", "Brush");
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
            a.item("OpenMemberPath", "String");
            a.item("HighMemberPath", "String");
            a.item("LowMemberPath", "String");
            a.item("CloseMemberPath", "String");
            a.item("VolumeMemberPath", "String");
            a.item("IsCustomCategoryStyleAllowed", "Boolean");
            a.item("TransitionInMode", "ExportedType:string:CategoryTransitionInMode");
            a.item("TransitionInMode@names", "Auto;FromZero;SweepFromLeft;SweepFromRight;SweepFromTop;SweepFromBottom;SweepFromCenter;AccordionFromLeft;AccordionFromRight;AccordionFromTop;AccordionFromBottom;Expand;SweepFromCategoryAxisMinimum;SweepFromCategoryAxisMaximum;SweepFromValueAxisMinimum;SweepFromValueAxisMaximum;AccordionFromCategoryAxisMinimum;AccordionFromCategoryAxisMaximum;AccordionFromValueAxisMinimum;AccordionFromValueAxisMaximum");
            a.item("IsTransitionInEnabled", "Boolean");
            a.item("AssigningCategoryStyleRef", "EventRef::assigningCategoryStyle");
            a.item("TypicalRef", "EventRef::typical");
            a.item("TypicalBasedOnRef", "EventRef::typicalBasedOn");
        }
        static d(a) {
            FinancialSeriesDescriptionMetadata.b(a);
            a.ab("FinancialSeries", FinancialSeriesDescriptionMetadata.a);
        }
    }
    FinancialSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialSeriesDescriptionMetadata, 'FinancialSeriesDescriptionMetadata');
    FinancialSeriesDescriptionMetadata.a = null;
    return FinancialSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/FinancialSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningCategoryStyleEventArgsDescriptionMetadata } from "./AssigningCategoryStyleEventArgsDescriptionMetadata";
import { FinancialEventArgsDescriptionMetadata } from "./FinancialEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
export let FinancialSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (FinancialSeriesDescriptionMetadata.a == null) {
                FinancialSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialSeriesDescriptionMetadata.c(FinancialSeriesDescriptionMetadata.a);
            }
            if (a.k(FinancialSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(FinancialSeriesDescriptionMetadata.a);
            AssigningCategoryStyleEventArgsDescriptionMetadata.d(a);
            FinancialEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            SeriesDescriptionMetadata.c(a);
            a.item("NegativeBrush", "Brush");
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
            a.item("OpenMemberPath", "String");
            a.item("HighMemberPath", "String");
            a.item("LowMemberPath", "String");
            a.item("CloseMemberPath", "String");
            a.item("VolumeMemberPath", "String");
            a.item("HighlightedOpenMemberPath", "String");
            a.item("HighlightedHighMemberPath", "String");
            a.item("HighlightedLowMemberPath", "String");
            a.item("HighlightedCloseMemberPath", "String");
            a.item("HighlightedVolumeMemberPath", "String");
            a.item("IsCustomCategoryStyleAllowed", "Boolean");
            a.item("TransitionInMode", "ExportedType:string:CategoryTransitionInMode");
            a.item("TransitionInMode@names", "Auto;FromZero;SweepFromLeft;SweepFromRight;SweepFromTop;SweepFromBottom;SweepFromCenter;AccordionFromLeft;AccordionFromRight;AccordionFromTop;AccordionFromBottom;Expand;SweepFromCategoryAxisMinimum;SweepFromCategoryAxisMaximum;SweepFromValueAxisMinimum;SweepFromValueAxisMaximum;AccordionFromCategoryAxisMinimum;AccordionFromCategoryAxisMaximum;AccordionFromValueAxisMinimum;AccordionFromValueAxisMaximum;FromParent");
            a.item("IsTransitionInEnabled", "Boolean");
            a.item("AssigningCategoryStyleRef", "EventRef::assigningCategoryStyle");
            a.item("TypicalRef", "EventRef::typical");
            a.item("TypicalBasedOnRef", "EventRef::typicalBasedOn");
        }
        static d(a) {
            FinancialSeriesDescriptionMetadata.b(a);
            a.ad("FinancialSeries", FinancialSeriesDescriptionMetadata.a);
        }
    }
    FinancialSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialSeriesDescriptionMetadata, 'FinancialSeriesDescriptionMetadata');
    FinancialSeriesDescriptionMetadata.a = null;
    return FinancialSeriesDescriptionMetadata;
})();
